### Name: DPbinary
### Title: Performs a Bayesian analysis for a semiparametric binary
###   regression model
### Aliases: DPbinary DPbinary.default
### Keywords: models

### ** Examples

## Not run: 
##D     # Bioassay Data Example
##D     # Cox, D.R. and Snell, E.J. (1989). Analysis of Binary Data. 2nd ed. 
##D     # Chapman and Hall. p. 7  
##D     # In this example there are 150 subjects at 5 different stimulus levels, 
##D     # 30 at each level.
##D 
##D       y<-c(rep(0,30-2),rep(1,2),
##D            rep(0,30-8),rep(1,8),
##D            rep(0,30-15),rep(1,15),
##D            rep(0,30-23),rep(1,23),
##D            rep(0,30-27),rep(1,27))
##D 
##D       x<-c(rep(0,30),
##D            rep(1,30),
##D            rep(2,30),
##D            rep(3,30),
##D            rep(4,30))
##D 
##D     # Initial state
##D       state <- NULL
##D 
##D     # MCMC parameters
##D       nburn<-50
##D       nsave<-200
##D       nskip<-5
##D       ndisplay<-100
##D       mcmc <- list(nburn=nburn,nsave=nsave,nskip=nskip,ndisplay=ndisplay,
##D                    tune=0.125)
##D 
##D     # Prior distribution
##D       prior <- list(a0=2,b0=1,beta0=rep(0,2), Sbeta0=diag(10000,2))
##D 
##D     # Fit the model
##D       fit1 <- DPbinary(y~x,prior=prior,mcmc=mcmc,state=state,status=TRUE) 
##D       fit1
##D 
##D     # Summary with HPD and Credibility intervals
##D       summary(fit1)
##D       summary(fit1,hpd=FALSE)
##D 
##D     # Plot model parameters (to see the plots gradually set ask=TRUE)
##D       plot(fit1)
##D       plot(fit1,nfigr=2,nfigc=2)        
##D 
##D     # Plot an specific model parameter (to see the plots gradually set ask=TRUE)
##D       plot(fit1,ask=FALSE,nfigr=1,nfigc=2,param="x")    
##D       plot(fit1,ask=FALSE,nfigr=1,nfigc=2,param="ncluster")     
##D       plot(fit1,ask=FALSE,param="link",nfigc=1,nfigr=1)
## End(Not run)      



